@@ -10,10 +10,9 @@ use Carp;
 use Module::CPANTS::Kwalitee;
 use IO::Capture::Stdout;
 use IO::Capture::Stderr;
-use YAML qw(LoadFile);
+use YAML::Syck qw(LoadFile);
 
-use vars qw($VERSION);
-$VERSION=0.73;
+use version; our $VERSION=qv('0.74');
 
 use Module::Pluggable search_path=>['Module::CPANTS::Kwalitee'];
 
