@@ -13,28 +13,30 @@ sub analyse {
     my $me=shift;
     my $files=$me->d->{files_array};
    
-    # use provides (META.yml) if available
-    my $meta=$me->d->{meta_yml};
-    if (my $provides=$meta->{provides}) {
-        while (my ($module,$data)=each %$provides) {
-            my $where='unknown';
-            if ($data->{file} =~ m|lib/|) {
-                $where='lib';
-            }
-            elsif ($data->{file} !~ m|/|) {
-                $where='base';
-            }
-            
-            push(@{$me->d->{modules}},
-                {
-                    module=>$module,
-                    file=>$data->{file},
-                    in_basedir=>$where eq 'base' ? 1 : 0,
-                    in_lib=> $where eq 'lib' ? 1 : 0,
-                });
-        }
-        return;
-    }
+# don't use META.yml's provides, because it lists every package defined in
+# the files, which leads to strange results.
+#    # use provides (META.yml) if available
+#    my $meta=$me->d->{meta_yml};
+#    if (my $provides=$meta->{provides}) {
+#        while (my ($module,$data)=each %$provides) {
+#            my $where='unknown';
+#            if ($data->{file} =~ m|lib/|) {
+#                $where='lib';
+#            }
+#            elsif ($data->{file} !~ m|/|) {
+#                $where='base';
+#            }
+#            
+#            push(@{$me->d->{modules}},
+#                {
+#                    module=>$module,
+#                    file=>$data->{file},
+#                    in_basedir=>$where eq 'base' ? 1 : 0,
+#                    in_lib=> $where eq 'lib' ? 1 : 0,
+#                });
+#        }
+#        return;
+#    }
     
     my @modules_basedir=grep {/^[^\/]+\.pm$/} @$files;
     if (@modules_basedir) {
@@ -122,7 +124,7 @@ sub kwalitee_indicators {
                 my $modules=$d->{modules};
                 return 0 unless $modules;
 
-                my @in_basedir=grep { $_->{file} !~ m|/| } @$modules;
+                my @in_basedir=grep { $_->{in_basedir} } @$modules;
                 return 1 if $d->{dir_lib} && @in_basedir == 0;
                 return 1 if @in_basedir == 1;
                 return 0;
